Struct ZwlrDataControlDeviceV1
pub struct ZwlrDataControlDeviceV1 { /* private fields */ }wayland and Linux only.Expand description
manage a data device for a seat
This interface allows a client to manage a seat’s selection.
When the seat is destroyed, this object becomes inert.
See also the Request enum for this interface.
Implementations
impl ZwlrDataControlDeviceV1
impl ZwlrDataControlDeviceV1
pub fn data_offer(&self, id: &ZwlrDataControlOfferV1)
pub fn data_offer(&self, id: &ZwlrDataControlOfferV1)
introduce a new wlr_data_control_offer
The data_offer event introduces a new wlr_data_control_offer object, which will subsequently be used in either the wlr_data_control_device.selection event (for the regular clipboard selections) or the wlr_data_control_device.primary_selection event (for the primary clipboard selections). Immediately following the wlr_data_control_device.data_offer event, the new data_offer object will send out wlr_data_control_offer.offer events to describe the MIME types it offers.
pub fn selection(&self, id: Option<&ZwlrDataControlOfferV1>)
pub fn selection(&self, id: Option<&ZwlrDataControlOfferV1>)
advertise new selection
The selection event is sent out to notify the client of a new wlr_data_control_offer for the selection for this device. The wlr_data_control_device.data_offer and the wlr_data_control_offer.offer events are sent out immediately before this event to introduce the data offer object. The selection event is sent to a client when a new selection is set. The wlr_data_control_offer is valid until a new wlr_data_control_offer or NULL is received. The client must destroy the previous selection wlr_data_control_offer, if any, upon receiving this event.
The first selection event is sent upon binding the wlr_data_control_device object.
pub fn finished(&self)
pub fn finished(&self)
this data control is no longer valid
This data control object is no longer valid and should be destroyed by the client.
pub fn primary_selection(&self, id: Option<&ZwlrDataControlOfferV1>)
pub fn primary_selection(&self, id: Option<&ZwlrDataControlOfferV1>)
advertise new primary selection
The primary_selection event is sent out to notify the client of a new wlr_data_control_offer for the primary selection for this device. The wlr_data_control_device.data_offer and the wlr_data_control_offer.offer events are sent out immediately before this event to introduce the data offer object. The primary_selection event is sent to a client when a new primary selection is set. The wlr_data_control_offer is valid until a new wlr_data_control_offer or NULL is received. The client must destroy the previous primary selection wlr_data_control_offer, if any, upon receiving this event.
If the compositor supports primary selection, the first primary_selection event is sent upon binding the wlr_data_control_device object.